Macro data_encoding_macro::decode_array
source · macro_rules! decode_array {
($($arg: tt)*) => { ... };
}Expand description
Defines a compile-time byte array by decoding a string literal
This macro takes a list of key: value, pairs (the last comma is required).
It takes the key-value pairs specifying the encoding to use to decode the
input (see new_encoding for the possible key-value pairs), the input
itself keyed by input, and the output keyed by name. The output must be
of the form [pub] {const|static} <name>.
Examples
#[macro_use]
extern crate data_encoding_macro;
decode_array!{
name: "const OCTAL",
symbols: "01234567",
padding: '=',
input: "237610==",
}